==> haskell-hunit-1.6.0.0-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 HUnit
version:              1.6.0.0
visibility:           public
id:                   HUnit-1.6.0.0-22oxvb8RM9BHmeY4GS3R8r
key:                  HUnit-1.6.0.0-22oxvb8RM9BHmeY4GS3R8r
license:              BSD-3-Clause
maintainer:           Simon Hengel <sol@typeful.net>
author:               Dean Herington
stability:            stable
homepage:             https://github.com/hspec/HUnit#readme
synopsis:             A unit testing framework for Haskell
description:
    HUnit is a unit testing framework for Haskell, inspired by the
    JUnit tool for Java, see: <http://www.junit.org>.

category:             Testing
abi:                  e8823ed492cbf0978358f116615d6df3
exposed:              True
exposed-modules:
    Test.HUnit Test.HUnit.Base Test.HUnit.Lang Test.HUnit.Terminal
    Test.HUnit.Text

hidden-modules:       Paths_HUnit
import-dirs:          /usr/lib/ghc-8.10.2/site-local/HUnit-1.6.0.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/HUnit-1.6.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/HUnit-1.6.0.0
hs-libraries:         HSHUnit-1.6.0.0-22oxvb8RM9BHmeY4GS3R8r
depends:
    base-4.14.1.0 call-stack-0.2.0-DbhLAp790QVAsLdZvx2oMa
    deepseq-1.4.4.0

haddock-interfaces:   /usr/share/doc/haskell-hunit/html/HUnit.haddock
haddock-html:         /usr/share/doc/haskell-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hunit-1.6.0.0-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 HUnit
version:              1.6.0.0
visibility:           public
id:                   HUnit-1.6.0.0-B83w6uLuSHUJoxVdSwJD4m
key:                  HUnit-1.6.0.0-B83w6uLuSHUJoxVdSwJD4m
license:              BSD-3-Clause
maintainer:           Simon Hengel <sol@typeful.net>
author:               Dean Herington
stability:            stable
homepage:             https://github.com/hspec/HUnit#readme
synopsis:             A unit testing framework for Haskell
description:
    HUnit is a unit testing framework for Haskell, inspired by the
    JUnit tool for Java, see: <http://www.junit.org>.

category:             Testing
abi:                  e623c2412e94af09b26fe56ca2a6e698
exposed:              True
exposed-modules:
    Test.HUnit Test.HUnit.Base Test.HUnit.Lang Test.HUnit.Terminal
    Test.HUnit.Text

hidden-modules:       Paths_HUnit
import-dirs:          /usr/lib/ghc-8.10.2/site-local/HUnit-1.6.0.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/HUnit-1.6.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/HUnit-1.6.0.0
hs-libraries:         HSHUnit-1.6.0.0-B83w6uLuSHUJoxVdSwJD4m
depends:
    base-4.14.1.0 call-stack-0.2.0-GaSR7xpoHcKCc3B0wbLwvx
    deepseq-1.4.4.0

haddock-interfaces:   /usr/share/doc/haskell-hunit/html/HUnit.haddock
haddock-html:         /usr/share/doc/haskell-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
